/* ###
 * IP: GHIDRA
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package agent.gdb.manager.evt;

import agent.gdb.manager.GdbState;
import agent.gdb.manager.parsing.GdbParsingUtils.GdbParseError;

/**
 * The event corresponding with "{@code *running}"
 */
public class GdbRunningEvent extends AbstractGdbEventWithStateChange {

	/**
	 * Construct a new event, parsing the tail for information
	 * 
	 * @param tail the text following the event type in the GDB/MI event record
	 * @throws GdbParseError if the tail cannot be parsed
	 */
	public GdbRunningEvent(CharSequence tail) throws GdbParseError {
		super(tail);
	}

	@Override
	public GdbState newState() {
		return GdbState.RUNNING;
	}

	/**
	 * Assume a thread ID is specified, and get that ID
	 * 
	 * @return the ID
	 */
	public String assumeThreadId() {
		return getInfo().getString("thread-id");
	}
}
