/* ###
 * IP: GHIDRA
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package ghidra.file.formats.android.dex.format;

import ghidra.app.util.bin.*;
import ghidra.file.formats.android.dex.util.DexUtil;
import ghidra.program.model.data.*;
import ghidra.util.exception.DuplicateNameException;

import java.io.IOException;

/**
 * 
 * https://android.googlesource.com/platform/art/+/master/libdexfile/dex/dex_file_structs.h
 *
 */
public class MethodAnnotationsItem implements StructConverter {

	private int methodIndex;
	private int annotationsOffset;

	private AnnotationSetItem _annotationSetItem;

	public MethodAnnotationsItem(BinaryReader reader, DexHeader dexHeader) throws IOException {
		methodIndex = reader.readNextInt();
		annotationsOffset = reader.readNextInt();

		if (annotationsOffset > 0) {
			long oldIndex = reader.getPointerIndex();
			try {
				reader.setPointerIndex(DexUtil.adjustOffset(annotationsOffset, dexHeader));
				_annotationSetItem = new AnnotationSetItem(reader, dexHeader);
			}
			finally {
				reader.setPointerIndex(oldIndex);
			}
		}
	}

	public int getMethodIndex() {
		return methodIndex;
	}

	public int getAnnotationsOffset() {
		return annotationsOffset;
	}

	public AnnotationSetItem getAnnotationSetItem() {
		return _annotationSetItem;
	}

	@Override
	public DataType toDataType() throws DuplicateNameException, IOException {
		DataType dataType = StructConverterUtil.toDataType(MethodAnnotationsItem.class);
		dataType.setCategoryPath(new CategoryPath("/dex"));
		return dataType;
	}

}
